========
Usage
========

To use PyParadox from the command line, type one of the following commands:

* ``pyparadox {ck2|eu4}`` (console)
* ``pyparadox-qt {ck2|eu4}`` (GUI)

Ideally, however, PyParadox is launched from Steam. To do this, right click on
your game in Steam, click ``Properties``, then click ``Set launch options...``
in the ``General`` tab. You want to enter the following value in the case of
Crusader Kings II::

    pyparadox-qt ck2

This will (hopefully) start up PyParadox when you start your game from Steam.

PyParadox comes with some default settings depending on your platform. In case
PyParadox is not configured directly, change the paths to your game executable
and mod path in the ``Configure`` dialog.
